==> libkdegames-kf5-18.12.0p0.tgz: lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration "Release"
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::KIOWidgets;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.0.0" )

# Import target "KF5KDEGamesPrivate" for configuration "Release"
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libkdegames-kf5-19.12.3.tgz: lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration "Release"
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons;KF5::Completion"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KDEGames.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.1.0" )

# Import target "KF5KDEGamesPrivate" for configuration "Release"
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KDEGamesPrivate.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
